==> xmedcon-0.10.7.tgz: include/m-config.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-config.h.in                                                 *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : (X)MedCon template configuration header (configure)      *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-config.h.in,v 1.22 2010/08/28 23:44:23 enlf Exp $
 */

/*
   Copyright (C) 1997-2010 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_CONFIG_H__
#define __M_CONFIG_H__

/* Define some version variables */
#define XMEDCON_MAJOR    "0"
#define XMEDCON_MINOR    "10"
#define XMEDCON_MICRO    "7"
#define XMEDCON_PRGR     "(X)MedCon"
#define XMEDCON_DATE     "15-Sep-2010"
#define XMEDCON_VERSION  "0.10.7"
#define XMEDCON_LIBVERS  "(X)MedCon 0.10.7 by Erik Nolf"

/* Define if format enabled */
#define MDC_INCLUDE_ACR   1
#define MDC_INCLUDE_GIF   1
#define MDC_INCLUDE_INW   1
#define MDC_INCLUDE_ANLZ  1
#define MDC_INCLUDE_CONC  1
#define MDC_INCLUDE_ECAT  1
#define MDC_INCLUDE_INTF  1
#define MDC_INCLUDE_DICM  1
#define MDC_INCLUDE_PNG   1
#define MDC_INCLUDE_NIFTI 1
#define MDC_INCLUDE_TPC   1    /* TPC ecat7 write */

/* Define some machine dependencies */
#define MDC_WORDS_BIGENDIAN  1
#define MDC_SIZEOF_SHORT     2
#define MDC_SIZEOF_INT       4
#define MDC_SIZEOF_LONG      4
#define MDC_ENABLE_LONG_LONG 0

#if MDC_ENABLE_LONG_LONG
#define MDC_SIZEOF_LONG_LONG 8
#endif


/* Define decompression program */
#define MDC_DECOMPRESS  "gunzip"

/* Define GLIB related stuff */
#define GLIBSUPPORTED 1

/* Define XMedCon related stuff */
#define GTKSUPPORTED 1
#if GTKSUPPORTED
#  define XMDCHELP "http://xmedcon.sourceforge.net"
#  ifdef _WIN32
#    define XMDCLUT  "C:\\Program Files\\XMedCon\\etc\\"
#    define XMDCRC   "C:\\Program Files\\XMedCon\\etc\\xmedconrc"
#  else
#    define XMDCLUT  "/etc/"
#    define XMDCRC   "/etc/xmedconrc"
#  endif
#endif

#endif

==> xmedcon-0.12.0p0.tgz: include/m-config.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-config.h.in                                                 *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : (X)MedCon template configuration header (configure)      *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-config.h.in,v 1.23 2011/12/27 00:46:06 enlf Exp $
 */

/*
   Copyright (C) 1997-2012 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_CONFIG_H__
#define __M_CONFIG_H__

/* Define some version variables */
#define XMEDCON_MAJOR    "0"
#define XMEDCON_MINOR    "12"
#define XMEDCON_MICRO    "0"
#define XMEDCON_PRGR     "(X)MedCon"
#define XMEDCON_DATE     "23-nov-2012"
#define XMEDCON_VERSION  "0.12.0"
#define XMEDCON_LIBVERS  "(X)MedCon 0.12.0 by Erik Nolf"

/* Define if format enabled */
#define MDC_INCLUDE_ACR   1
#define MDC_INCLUDE_GIF   1
#define MDC_INCLUDE_INW   1
#define MDC_INCLUDE_ANLZ  1
#define MDC_INCLUDE_CONC  1
#define MDC_INCLUDE_ECAT  1
#define MDC_INCLUDE_INTF  1
#define MDC_INCLUDE_DICM  1
#define MDC_INCLUDE_PNG   1
#define MDC_INCLUDE_NIFTI 1
#define MDC_INCLUDE_TPC   1    /* TPC ecat7 write */

/* Define some machine dependencies */
#define MDC_WORDS_BIGENDIAN  1
#define MDC_SIZEOF_SHORT     2
#define MDC_SIZEOF_INT       4
#define MDC_SIZEOF_LONG      4
#define MDC_ENABLE_LONG_LONG 0

#if MDC_ENABLE_LONG_LONG
#define MDC_SIZEOF_LONG_LONG 8
#endif


/* Define decompression program */
#define MDC_DECOMPRESS  "gunzip"

/* Define GLIB related stuff */
#define GLIBSUPPORTED 1

/* Define XMedCon related stuff */
#define GTKSUPPORTED 1
#if GTKSUPPORTED
#  define XMDCHELP "http://xmedcon.sourceforge.net"
#  ifdef _WIN32
#    define XMDCLUT  "C:\\Program Files\\XMedCon\\etc\\"
#    define XMDCRC   "C:\\Program Files\\XMedCon\\etc\\xmedconrc"
#  else
#    define XMDCLUT  "/etc/"
#    define XMDCRC   "/etc/xmedconrc"
#  endif
#endif

#endif
